@@ -1,7 +1,7 @@
 /*
 *
 * kkconsui common routines
-* $Id: conscommon.cc,v 1.23 2002/08/14 12:03:43 konst Exp $
+* $Id: conscommon.cc,v 1.27 2004/06/21 13:04:31 konst Exp $
 *
 * Copyright (C) 1999-2001 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -166,7 +166,7 @@ int kwherey() {
 }
 
 void kwriteatf(int x, int y, int c, const char *fmt, ...) {
-    char buf[10240];
+    char buf[65535];
     va_list ap;
     
     va_start(ap, fmt);    
@@ -184,14 +184,14 @@ void kwriteat(int x, int y, const char *msg, int c) {
     refresh();
 }
 
-int keypressed() {
+int keypressed(bool wait) {
     struct timeval tv;
     fd_set readfds;
     tv.tv_sec = tv.tv_usec = 0;
 
     FD_ZERO(&readfds);
     FD_SET(0, &readfds);
-    select(1, &readfds, 0, 0, &tv);
+    select(1, &readfds, 0, 0, wait ? 0 : &tv);
 
     return FD_ISSET(0, &readfds);
 }
@@ -214,13 +214,6 @@ void setbeep(int freq, int duration) {
     fflush(stdout);
 }
 
-void delay(int milisec) {
-    struct timeval tv;
-    tv.tv_sec = 0;
-    tv.tv_usec = milisec*1000;
-    select(0, 0, 0, 0, &tv);
-}
-
 int string2key(const string &adef) {
     int r;
     string d, ck;
@@ -256,7 +249,7 @@ extern "C" {
 #include <fribidi/fribidi.h>
 }
 
-string makebidi(const string &buf, int lpad = 0) {
+string makebidi(const string &buf, int lpad) {
     if(!use_fribidi) return buf;
 
     FriBidiChar *us, *out_us;
