@@ -31,25 +31,17 @@
 
 #include <time.h>
 
-#include <libicq2000/buffer.h>
-#include <libicq2000/socket.h>
 #include <libicq2000/events.h>
 #include <libicq2000/constants.h>
 #include <libicq2000/Contact.h>
+#include <libicq2000/ContactTree.h>
 #include <libicq2000/ContactList.h>
-#include <libicq2000/custom_marshal.h>
-#include <libicq2000/Translator.h>
-#include <libicq2000/RequestIDCache.h>
-#include <libicq2000/ICBMCookieCache.h>
-#include <libicq2000/DirectClient.h>
-#include <libicq2000/DCCache.h>
-#include <libicq2000/SMTPClient.h>
 #include <libicq2000/userinfoconstants.h>
-#include <libicq2000/MessageHandler.h>
 
-namespace ICQ2000 {
+namespace ICQ2000
+{
   
-  // declare some SNAC classes - vastly decreases header dependancies
+  /* predeclare classes */
   class MessageSNAC;
   class MessageACKSNAC;
   class MessageOfflineUserSNAC;
@@ -60,13 +52,28 @@ namespace ICQ2000 {
   class BuddyOfflineSNAC;
   class UserInfoSNAC;
   class OutSNAC;
+  class DirectClient;
+  class DCCache;
+  class MessageHandler;
+  class RequestIDCache;
+  class RequestIDCacheValue;
+  class ICBMCookieCache;
+  class SMTPClient;
+  class SocketClient;
+  class Buffer;
+  class TCPSocket;
+  class TCPServer;
+  class Translator;
+  class FileTransferClient;
+  class FTCache;
 
   /**
    *  The main library object.  This is the object the user interface
    *  instantiates for a connection, hooks up to signal on and has the
    *  methods to connect, disconnect and send events from.
    */
-  class Client : public sigslot::has_slots<> {
+  class Client : public sigslot::has_slots<>
+  {
    private:
     enum State { NOT_CONNECTED,
 		 AUTH_AWAITING_CONN_ACK,
@@ -85,9 +92,6 @@ namespace ICQ2000 {
     bool m_web_aware;
     unsigned short m_random_group;
 
-    std::string m_default_group_name;
-    unsigned short m_default_group;
-
     std::string m_authorizerHostname;
     unsigned short m_authorizerPort;
 
@@ -102,34 +106,38 @@ namespace ICQ2000 {
     unsigned short m_client_seq_num;
     unsigned int m_requestid;
     
-    Translator m_translator;
+    Translator * m_translator;
 
-    ContactList m_contact_list;
+    ContactTree m_contact_tree;
     
     ContactList m_visible_list;
     ContactList m_invisible_list;
 
-    MessageHandler m_message_handler;
+    bool m_fetch_sbl;
+
+    MessageHandler * m_message_handler;
 
     unsigned char *m_cookie_data;
     unsigned short m_cookie_length;
 
     unsigned int m_ext_ip;
     bool m_use_portrange;
+    bool m_use_typing_notif;
     unsigned short m_upper_port, m_lower_port;
-    TCPSocket m_serverSocket;
-    TCPServer m_listenServer;
+    TCPSocket * m_serverSocket;
+    TCPServer * m_listenServer;
 
-    SMTPClient m_smtp;
+    SMTPClient * m_smtp;
 
-    DCCache m_dccache;
+    DCCache * m_dccache;
+    FTCache * m_ftcache;
 
     time_t m_last_server_ping;
 
-    RequestIDCache m_reqidcache;
-    ICBMCookieCache m_cookiecache;
+    RequestIDCache * m_reqidcache;
+    ICBMCookieCache * m_cookiecache;
 
-    Buffer m_recv;
+    Buffer * m_recv;
    
     void Init();
     unsigned short NextSeqNum();
@@ -160,7 +168,6 @@ namespace ICQ2000 {
     void SignalLog(LogEvent::LogType type, const std::string& msg);
     void SignalUserOnline(BuddyOnlineSNAC *snac);
     void SignalUserOffline(BuddyOfflineSNAC *snac);
-    void SignalServerBasedContactList(const ContactList& l);
     void SignalAddSocket(int fd, SocketEvent::Mode m);
     void SignalRemoveSocket(int fd);
     // ------------------ Outgoing packets -------------------
@@ -184,7 +191,8 @@ namespace ICQ2000 {
     void SendAddICBMParameter();
     void SendSetUserInfo();
     void SendLogin();
-    void SendOfflineMessagesRequest();
+    void SendRequestSBL();
+    void SendSBLReceivedACK();
     void SendOfflineMessagesACK();
 
     void SendAdvancedACK(MessageSNAC *snac);
@@ -193,9 +201,6 @@ namespace ICQ2000 {
 
     void HandleUserInfoSNAC(UserInfoSNAC *snac);
 
-    Buffer::marker FLAPHeader(Buffer& b, unsigned char channel);
-    void FLAPFooter(Buffer& b, Buffer::marker& mk);
-
     void FLAPwrapSNAC(Buffer& b, const OutSNAC& snac);
     void FLAPwrapSNACandSend(const OutSNAC& snac);
 
@@ -217,13 +222,17 @@ namespace ICQ2000 {
 
     ContactRef getUserInfoCacheContact(unsigned int reqid);
 
+    void mergeSBL(ContactTree& tree);
+
     void ICBMCookieCache_expired_cb(MessageEvent *ev);
     void dccache_expired_cb(DirectClient *dc);
+    void ftcache_expired_cb(FileTransferClient *ftc);
     void reqidcache_expired_cb( RequestIDCacheValue *v );
     void dc_connected_cb(SocketClient *dc);
     void dc_log_cb(LogEvent *ev);
     void dc_socket_cb(SocketEvent *ev);
     void dc_messageack_cb(MessageEvent *ev);
+    void ftc_messageack_cb(MessageEvent *ev);
 
     bool SendDirect(MessageEvent *ev);
 
@@ -265,6 +274,8 @@ namespace ICQ2000 {
      */
     sigslot::signal1<ConnectedEvent*> connected;
 
+    sigslot::signal1<SBLReceivedEvent*> sbl_received;
+
     /**
      *  The signal to connect to for listening to DisconnectedEvent's.
      *  A DisconnectedEvent is signalled when you were disconnected
@@ -377,23 +388,33 @@ namespace ICQ2000 {
      *  event is finished and deleted from memory by the library.
      */
     sigslot::signal1<SearchResultEvent*> search_result;
-    
-    sigslot::signal1<ServerBasedContactEvent*> server_based_contact_list;
 
-    sigslot::signal1<PasswordChangeEvent*> password_changed;
+    /**
+     *  Signal when an incoming file transfer request is received.
+     */
+    sigslot::signal1<FileTransferEvent*> filetransfer_incoming_signal;
+    
+    /**
+     *  Signal when a FileTransferEvent object is updated.
+     */
+    sigslot::signal1<FileTransferEvent*> filetransfer_update_signal;
     
     // -------------
 
     // -- Send calls --
     void SendEvent(MessageEvent *ev);
 
+    // -- File Transfer methods --
+    void SendFileTransfer(FileTransferEvent *ev);
+    void SendFileTransferACK(FileTransferEvent *ev);
+    void CancelFileTransfer(FileTransferEvent *ev);
+	
     // -- Set Status --
     void setStatus(const Status st);
     void setStatus(const Status st, bool inv);
     void setInvisible(bool inv);
     void setWebAware(bool wa);
     void setRandomChatGroup(unsigned short group);
-    void changePassword(const std::string &new_pass);
     
     Status getStatus() const;
     bool getInvisible() const;
@@ -405,27 +426,29 @@ namespace ICQ2000 {
 
     void uploadSelfDetails();
     
-    void setServerSideGroup(const std::string &group_name, unsigned short group_id);
-
+    void uploadServerBasedContact(const ContactRef& c);
+    void uploadServerBasedGroup(const ContactTree::Group& gp);
     void uploadServerBasedContactList();
-    void uploadServerBasedContactList(const ContactList &l);
+
+    void updateServerBasedContact(const ContactRef& c);
+
+    void removeServerBasedContact(const ContactRef& c);
+    void removeServerBasedGroup(const ContactTree::Group& gp);
     void removeServerBasedContactList();
-    void removeServerBasedContactList(const ContactList &l);
-    
+
     // -- Contact List --
-    void addContact(ContactRef c);
-    void removeContact(const unsigned int uin);
     void addVisible(ContactRef c);
     void removeVisible(const unsigned int uin);
     void addInvisible(ContactRef c);
     void removeInvisible(const unsigned int uin);
     ContactRef getContact(const unsigned int uin);
 
-    ContactList& getContactList();
+    ContactTree& getContactTree();
 
     void fetchSimpleContactInfo(ContactRef c);
     void fetchDetailContactInfo(ContactRef c);
     void fetchServerBasedContactList();
+    void fetchServerBasedContactList(int); // the conditional form - TODO!
     void fetchSelfSimpleContactInfo();
     void fetchSelfDetailContactInfo();
 
@@ -493,6 +516,8 @@ namespace ICQ2000 {
     void setClientBindHost(const std::string& host);
     std::string getClientBindHost() const;
 
+    void setTypingNotifications(bool b);
+
     void Poll();
     void socket_cb(int fd, SocketEvent::Mode m);
 
@@ -503,7 +528,8 @@ namespace ICQ2000 {
      * & DisconnectedEvents the client gets
      */
     bool isConnected() const;
-    
+
+    void set_translator(Translator * t);
   };
 }
 
