@@ -33,6 +33,7 @@
 #include <libicq2000/constants.h>
 
 #include <libicq2000/ContactList.h>
+#include <libicq2000/ContactTree.h>
 
 namespace ICQ2000 {
 
@@ -207,7 +208,7 @@ namespace ICQ2000 {
   };
 
   // ============================================================================
-  //  ContactListEvents (user added, user removed)
+  //  ContactListEvents (user added, user removed, group added, group removed)
   // ============================================================================
 
   /**
@@ -220,22 +221,18 @@ namespace ICQ2000 {
      */
     enum EventType {
       UserAdded,
-      UserRemoved
+      UserRemoved,
+      UserRelocated,
+      GroupAdded,
+      GroupRemoved,
+      GroupChange,
+      CompleteUpdate
     };
     
-   protected:
-    /**
-     *  The contact this event refers to.
-     */
-    ContactRef m_contact;
-
    public:
-    ContactListEvent(ContactRef c);
+    ContactListEvent();
     virtual ~ContactListEvent();
     
-    ContactRef getContact() const;
-    unsigned int getUIN() const;
-
     /**
      *  get the type of ContactListEvent
      *
@@ -244,26 +241,120 @@ namespace ICQ2000 {
     virtual EventType getType() const = 0;
   };
 
+  class UserContactListEvent : public ContactListEvent 
+  {
+   private:
+    ContactRef m_contact;
+    ContactTree::Group& m_group;
+    
+   public:
+    UserContactListEvent(const ContactRef& c, ContactTree::Group& gp);
+    
+    ContactRef getContact() const;
+    ContactTree::Group& get_group();
+    unsigned int getUIN() const;
+  };
+  
   /**
    *  The event signalled when a user is added.
    */
-  class UserAddedEvent : public ContactListEvent {
+  class UserAddedEvent : public UserContactListEvent {
    public:
-    UserAddedEvent(ContactRef c);
+    UserAddedEvent(const ContactRef& c, ContactTree::Group& gp);
     EventType getType() const;
   };
 
   /**
    *  The event signalled when a user is about to be removed.
    */
-  class UserRemovedEvent : public ContactListEvent {
+  class UserRemovedEvent : public UserContactListEvent {
    public:
-    UserRemovedEvent(ContactRef c);
+    UserRemovedEvent(const ContactRef& c, ContactTree::Group& gp);
     EventType getType() const;
   };
 
+  /**
+   *  The event signalled when a user is being moved between groups.
+   */
+  class UserRelocatedEvent : public UserContactListEvent {
+   protected:
+    ContactTree::Group& m_old_group;
+
+   public:
+    UserRelocatedEvent(const ContactRef& c, ContactTree::Group& new_gp, ContactTree::Group& old_gp);
+    EventType getType() const;
+
+    ContactTree::Group& get_old_group();
+  };
+
+  /**
+   *  Group related ContactList events
+   */
+  class GroupContactListEvent : public ContactListEvent 
+  {
+   private:
+    const ContactTree::Group& m_group;
+    
+   public:
+    GroupContactListEvent(const ContactTree::Group& gp);
+    
+    const ContactTree::Group& get_group() const;
+  };
+  
+  /**
+   *  The event signalled when a group is added.
+   */
+  class GroupAddedEvent : public GroupContactListEvent
+  {
+   public:
+    GroupAddedEvent(const ContactTree::Group& gp);
+    EventType getType() const;
+  };
+
+  /**
+   *  The event signalled when a group is removed.
+   */
+  class GroupRemovedEvent : public GroupContactListEvent
+  {
+   public:
+    GroupRemovedEvent(const ContactTree::Group& gp);
+    EventType getType() const;
+  };
+
+  /**
+   *  The event signalled when a group is removed.
+   */
+  class GroupChangeEvent : public GroupContactListEvent
+  {
+   public:
+    GroupChangeEvent(const ContactTree::Group& gp);
+    EventType getType() const;
+  };
+
+  /**
+   *  The event signalled when the contact list is completely
+   *  refreshed (from the server)
+   */
+  class CompleteUpdateEvent : public ContactListEvent
+  {
+   public:
+    CompleteUpdateEvent();
+    EventType getType() const;
+  };
+
+  /* Konst's temporary SBL hack */
+
+  class SBLReceivedEvent : public Event
+  {
+   public:
+    SBLReceivedEvent(const ContactTree &atree): tree(atree)
+	{ }
+
+    ContactTree tree;
+  };
+
   // ============================================================================
-  //  ContactEvents (queue changes, status change, user info change)
+  //  ContactEvents (status change, user info change)
   // ============================================================================
 
   /**
@@ -353,6 +444,7 @@ namespace ICQ2000 {
       UserAdd,
       Email,
       WebPager,
+      FileTransfer,
       Contacts
     };
 
@@ -639,6 +731,86 @@ namespace ICQ2000 {
     MessageType getType() const;
   };
 
+  /**
+   *  A File Transfer 
+   */  
+  class FileTransferEvent : public ICQMessageEvent
+  {
+   public:
+    enum State
+    {
+      NOT_CONNECTED,
+      SEND,
+      RECEIVE,
+      WAIT_RESPONS,
+      ACCEPTED,
+      REJECTED,
+      ERROR,
+      COMPLETE,
+      CANCELLED,
+      TIMEOUT,
+      CLOSE
+    };
+    
+   private:
+    State m_state;
+	
+    std::string m_error;
+    std::string m_message, m_description, m_refusal_message, m_save_path;
+    std::list<std::string> m_files;
+    unsigned int m_size, m_speed;
+    unsigned int m_totsize, m_totpos;
+    unsigned int m_pos, m_totfiles, m_currfile;
+    unsigned short m_port;
+    unsigned short m_seqnum;
+
+   public:
+    FileTransferEvent(ContactRef c, const std::string& msg, const std::string& desc,
+		      unsigned int size, unsigned short seqnum);
+
+    void setState(State st);
+    State getState();
+    void setError(const std::string& str);
+    std::string getError();
+    void addFile(const std::string& file);
+    std::string getFile();
+    unsigned int getFilesInQueue();
+    unsigned int getSpeed();
+    void setSpeed(const unsigned int speed);
+    std::string getMessage() const;
+    std::string getDescription() const;
+    void setDescription(const std::string& str);
+    std::string getSavePath() const;
+    void setSavePath(const std::string& str);
+
+    unsigned int getSize() const;
+    unsigned int getTotalSize() const;
+    unsigned int getTotalPos() const;
+    unsigned int getPos() const;
+    unsigned int getTotalFiles() const;
+    unsigned int getCurrFile() const;
+   
+    void setTotalSize(unsigned int t_size);     
+    void setSize(unsigned int size);
+    void setPos(unsigned int pos);
+    void setTotalPos(unsigned int pos);
+    void setTotalFiles(unsigned int nr);
+    void setCurrFile(unsigned int pos);
+    
+    unsigned short getPort() const;
+    void setPort(unsigned short port);
+    
+    std::string getRefusalMessage() const;
+    void setRefusalMessage(const std::string& s);
+
+    unsigned short getSeqNum() const;
+    void setSeqNum(unsigned short seqnum);
+    
+    MessageType getType() const;
+    ICQMessageEvent* copy() const;
+  };
+
+  
   /**
    *  A contacts message
    */
@@ -700,6 +872,7 @@ namespace ICQ2000 {
   /**
    *  The event signalled when entries from the server-based contact list is received.
    */
+  /*
   class ServerBasedContactEvent : public Event {
    public:
     enum SBLType {
@@ -728,6 +901,7 @@ namespace ICQ2000 {
     ContactList& getContactList();
     SBLType getType() const { return m_type; }
   };
+  */
 
   // ============================================================================
   //  NewUINEvent
@@ -800,24 +974,6 @@ namespace ICQ2000 {
     unsigned int getMaxAvg() const { return m_maxavg; }
   };
 
-  /**
-   *  Password change
-   */
-  class PasswordChangeEvent : public Event {
-   private:
-    bool m_success;
-    std::string m_new_password;
-
-   public:
-    PasswordChangeEvent(const std::string &new_pass): 
-      m_new_password(new_pass) { };
-
-    bool isSuccess() const { return m_success; }
-    std::string getPassword() const { return m_new_password; }
-
-    void setSuccess(bool success) { m_success = success; }
-  };
-
 } 
 
 #endif
