@@ -19,10 +19,10 @@
  *
  */
 
-#include <libicq2000/DirectClient.h>
+#include "DirectClient.h"
 
-#include <libicq2000/ICQ.h>
-#include <libicq2000/constants.h>
+#include "ICQ.h"
+#include "constants.h"
 
 #include "sstream_fix.h"
 
@@ -48,12 +48,11 @@ namespace ICQ2000 {
    * Constructor when receiving an incoming connection
    */
   DirectClient::DirectClient(ContactRef self, TCPSocket *sock, MessageHandler *mh,
-			     ContactList *cl, unsigned int ext_ip, unsigned short server_port,
-			     Translator* translator)
-    : m_state(WAITING_FOR_INIT), m_recv(translator),
+			     ContactTree *cl, unsigned int ext_ip, unsigned short server_port)
+    : m_state(WAITING_FOR_INIT), m_recv(),
       m_self_contact(self), m_contact(NULL), m_contact_list(cl), 
       m_message_handler(mh), m_incoming(true), m_local_ext_ip(ext_ip),
-      m_local_server_port(server_port), m_translator(translator)
+      m_local_server_port(server_port)
   {
     m_socket = sock;
     Init();
@@ -63,10 +62,10 @@ namespace ICQ2000 {
    * Constructor for making an outgoing connection
    */
   DirectClient::DirectClient(ContactRef self, ContactRef c, MessageHandler *mh, unsigned int ext_ip,
-			     unsigned short server_port, Translator *translator)
-    : m_state(NOT_CONNECTED), m_recv(translator), m_self_contact(self), 
+			     unsigned short server_port)
+    : m_state(NOT_CONNECTED), m_recv(), m_self_contact(self), 
       m_contact(c), m_message_handler(mh), m_incoming(false), m_local_ext_ip(ext_ip),
-      m_local_server_port(server_port), m_translator(translator)
+      m_local_server_port(server_port)
       
   {
     Init();
@@ -74,7 +73,8 @@ namespace ICQ2000 {
     m_remote_uin = c->getUIN();
   }
 
-  DirectClient::~DirectClient() {
+  DirectClient::~DirectClient()
+  {
     m_msgcache.expireAll();
     
     while (!m_msgqueue.empty()) {
@@ -86,10 +86,11 @@ namespace ICQ2000 {
     delete m_socket;
   }
 
-  void DirectClient::Init() {
+  void DirectClient::Init()
+  {
     m_seqnum = 0xFFFF;
     m_msgcache.setDefaultTimeout(30);
-    m_msgcache.expired.connect( this, &DirectClient::expired_cb );
+    m_msgcache.expired.connect( this, &DirectClient::expired_cb) ;
   }
 
   void DirectClient::Connect() {
@@ -104,12 +105,21 @@ namespace ICQ2000 {
     m_socket->Connect();
     SignalAddSocket( m_socket->getSocketHandle(), SocketEvent::WRITE );
 
-    m_session_id = (unsigned int)(0xffffffff*(rand()/(RAND_MAX+1.0)));
+    if (m_contact->getDCCookie() != 0)
+    {
+      m_session_id = m_contact->getDCCookie();
+    }
+    else
+    {
+      m_session_id = (unsigned int)(0xffffffff*(rand()/(RAND_MAX+1.0)));
+    }
+    
 
     m_state = WAITING_FOR_INIT_ACK;
   }
 
-  void DirectClient::FinishNonBlockingConnect() {
+  void DirectClient::FinishNonBlockingConnect()
+  {
     SendInitPacket();
   }
 
@@ -156,7 +166,7 @@ namespace ICQ2000 {
       if (m_recv.remains() < length) return; // waiting for more of the packet
 
 
-      Buffer sb(m_translator);
+      Buffer sb;
       m_recv.chopOffBuffer( sb, length+2 );
 
       ostringstream ostr;
@@ -258,7 +268,7 @@ namespace ICQ2000 {
   }
 
   void DirectClient::SendInitPacket() {
-    Buffer b(m_translator);
+    Buffer b;
     b.setLittleEndian();
     Buffer::marker m1 = b.getAutoSizeShortMarker();
 
@@ -385,7 +395,7 @@ namespace ICQ2000 {
   }
 
   void DirectClient::SendInit2() {
-    Buffer b(m_translator);
+    Buffer b;
     b.setLittleEndian();
     Buffer::marker m1 = b.getAutoSizeShortMarker();
     b << (unsigned char) 0x03       // start byte
@@ -408,7 +418,7 @@ namespace ICQ2000 {
   }
 
   void DirectClient::ParsePacket(Buffer& b) {
-    Buffer c(m_translator);
+    Buffer c;
     if (!Decrypt(b, c)) throw ParseException("Decrypting failed");
     ParsePacketInt(c);
   }
@@ -453,23 +463,55 @@ namespace ICQ2000 {
 
     case V6_TCP_START:
     {
-      bool ack = m_message_handler->handleIncoming( icqsubtype );
-      if (ack) SendPacketAck(icqsubtype);
-      break;
+      if (icqsubtype->getType() == MSG_Type_FT)
+      {
+	FTICQSubType *fticqsubtype = static_cast<FTICQSubType*>( icqsubtype );
+	FileTransferEvent *ev = m_message_handler->handleIncomingFT( fticqsubtype, true );
+	m_msgcache.insert( seqnum, ev );
+      }
+      else
+      {
+	bool ack = m_message_handler->handleIncoming( icqsubtype );
+	if (ack) SendPacketAck(icqsubtype);
+      }
     }
-
+    break;
     case V6_TCP_ACK:
-      if ( m_msgcache.exists(seqnum) ) {
+      if ( m_msgcache.exists(seqnum) )
+      {
 	MessageEvent *ev = m_msgcache[seqnum];
 	ev->setDirect(true);
 	m_message_handler->handleIncomingACK( ev, icqsubtype );
 	m_msgcache.remove(seqnum);
-	delete ev;
-      } else {
+	if (icqsubtype->getType() != MSG_Type_FT)
+	  delete ev;  //WARNING!!! FileTransferEvent shall not be deleted here?
+	   
+      }
+      else
+      {
 	SignalLog(LogEvent::WARN, "Received Direct ACK for unknown message");
       }      
       break;
 
+    case V6_TCP_CANCEL:
+      // FileTransfer was cancelled before we responded
+      if ( icqsubtype->getType() == MSG_Type_FT
+	   && m_msgcache.exists(seqnum) )
+      {
+	MessageEvent *ev = m_msgcache[seqnum];
+	if ( ev->getType() == MessageEvent::FileTransfer )
+	{
+	  FileTransferEvent *eev = static_cast<FileTransferEvent*>(ev);
+	  m_message_handler->handleIncomingFTCancel( eev );
+	  m_msgcache.remove(seqnum);
+	}
+	
+      }
+      else
+      {
+	SignalLog(LogEvent::WARN, "Received Direct Cancel for unknown message");
+      }      
+      break;
     default:
       ostr << "Unknown TCP Command received 0x" << command;
       throw ParseException( ostr.str() );
@@ -620,8 +662,9 @@ namespace ICQ2000 {
 
   }
 
-  void DirectClient::SendInitAck() {
-    Buffer b(m_translator);
+  void DirectClient::SendInitAck()
+  {
+    Buffer b;
     b.setLittleEndian();
     Buffer::marker m1 = b.getAutoSizeShortMarker();
     b << (unsigned int)0x00000001;
@@ -629,8 +672,9 @@ namespace ICQ2000 {
     Send(b);
   }
 
-  void DirectClient::SendPacketAck(ICQSubType *icqsubtype) {
-    Buffer b(m_translator);
+  void DirectClient::SendPacketAck(ICQSubType *icqsubtype)
+  {
+    Buffer b;
 
     b.setLittleEndian();
     b << (unsigned int)0x00000000 // checksum (filled in by Encrypt)
@@ -642,13 +686,14 @@ namespace ICQ2000 {
       << (unsigned int)0x00000000;
     
     icqsubtype->Output(b);
-    Buffer c(m_translator);
+    Buffer c;
     Encrypt(b,c);
     Send(c);
   }
 
-  void DirectClient::SendPacketEvent(MessageEvent *ev) {
-    Buffer b(m_translator);
+  void DirectClient::SendPacketEvent(MessageEvent *ev)
+  {
+    Buffer b;
 
     unsigned short seqnum = NextSeqNum();
 
@@ -656,7 +701,7 @@ namespace ICQ2000 {
     if (ist == NULL) return;
 
     ist->setAdvanced(true);
-
+    
     b.setLittleEndian();
     b << (unsigned int)0x00000000 // checksum (filled in by Encrypt)
       << V6_TCP_START
@@ -667,13 +712,20 @@ namespace ICQ2000 {
       << (unsigned int)0x00000000;
     ist->Output(b);
 
-    Buffer c(m_translator);
+    Buffer c;
     Encrypt(b,c);
     Send(c);
 
-    delete ist;
-
+    // Save seqnum so later ACK or CANCEL could be sent.
+    if (ist->getType() == MSG_Type_FT)
+    {
+      FileTransferEvent *fev = static_cast<FileTransferEvent*>(ev);
+      fev->setSeqNum(seqnum);
+    }
+    
     m_msgcache.insert(seqnum, ev);
+
+    delete ist;
   }
 
   void DirectClient::Send(Buffer &b) {
@@ -689,7 +741,66 @@ namespace ICQ2000 {
     }
   }
 
-  void DirectClient::SendEvent(MessageEvent *ev) {
+
+  void DirectClient::SendFTACK(FileTransferEvent *ev)
+  {
+    FTICQSubType icqsubtype;
+    icqsubtype.setAdvanced(true);
+    icqsubtype.setSeqNum(ev->getSeqNum());
+    icqsubtype.setACK(true);
+    if (ev->getState() == FileTransferEvent::ACCEPTED)
+    {
+      icqsubtype.setPort(ev->getPort());
+      icqsubtype.setRevPort(ev->getPort());
+      icqsubtype.setSize(0);
+      icqsubtype.setMessage("");
+	    
+      // port numbers, etc..
+    }
+    else
+    {
+      icqsubtype.setStatus( AcceptStatus_Denied );
+      icqsubtype.setPort(0);
+      icqsubtype.setSize(0);
+      icqsubtype.setMessage( ev->getRefusalMessage() );
+    }
+    SendPacketAck(&icqsubtype);
+    while (m_msgcache.exists(ev->getSeqNum()))
+    {
+      m_msgcache.remove(ev->getSeqNum());
+    }
+  }
+
+  void DirectClient::SendFTCancel(FileTransferEvent *ev)
+  {
+    FTICQSubType fist;
+    fist.setAdvanced(true);
+    fist.setSeqNum(ev->getSeqNum());
+
+    fist.setPort(0);
+    fist.setSize(0);
+    fist.setMessage( "" );
+
+    Buffer b;
+    b.setLittleEndian();
+    b << (unsigned int)0x00000000 // checksum (filled in by Encrypt)
+      << V6_TCP_CANCEL
+      << (unsigned short)0x000e
+      << fist.getSeqNum()
+      << (unsigned int)0x00000000
+      << (unsigned int)0x00000000
+      << (unsigned int)0x00000000;
+    fist.Output(b);
+
+    Buffer c;
+    Encrypt(b,c);
+    Send(c);
+
+    m_msgcache.remove(ev->getSeqNum());
+  }
+
+  void DirectClient::SendEvent(MessageEvent *ev)
+  {
 
     if (m_state == CONNECTED) {
       // send straight away
