@@ -1,7 +1,7 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.195 2005/01/26 23:52:47 konst Exp $
+* $Id: centericq.cc,v 1.197 2005/05/02 15:23:58 konst Exp $
 *
 * Copyright (C) 2001-2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -77,9 +77,6 @@ void centericq::exec() {
 
 	if(updateconf()) {
 	    manager.exec();
-#ifdef BUILD_KONST
-	    defaultcontacts(rus);
-#endif
 	}
 
 	regmode = false;
@@ -113,10 +110,6 @@ void centericq::exec() {
     conf.save();
 }
 
-void centericq::defaultcontacts(bool rus) {
-    clist.addnew(imcontact(17502151, icq), false);
-}
-
 bool centericq::checkpasswords() {
     protocolname pname;
     icqconf::imaccount ia;
@@ -168,10 +161,12 @@ void centericq::mainloop() {
     face.draw();
 
     while(!finished) {
-	face.status(_("%s contact menu, %s change status, %s general actions, %s quit"),
+	face.status(_("%s contact menu, %s status, %s general, %s/%s next/prev chat, %s quit"),
 	    face.getstatkey(key_user_menu, section_contact).c_str(),
 	    face.getstatkey(key_change_status, section_contact).c_str(),
 	    face.getstatkey(key_general_menu, section_contact).c_str(),
+	    face.getstatkey(key_next_chat, section_contact).c_str(),
+	    face.getstatkey(key_prev_chat, section_contact).c_str(),
 	    face.getstatkey(key_quit, section_contact).c_str());
 
 	face.xtermtitle();
