@@ -1,7 +1,7 @@
 /*
 *
 * centericq Jabber protocol handling class
-* $Id: jabberhook.cc,v 1.81 2005/01/26 23:52:48 konst Exp $
+* $Id: jabberhook.cc,v 1.85 2005/08/26 11:01:49 konst Exp $
 *
 * Copyright (C) 2002-2005 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -109,16 +109,18 @@ void jabberhook::connect() {
     icqconf::imaccount acc = conf.getourid(proto);
     string jid = getourjid();
 
+
     log(logConnecting);
 
     auto_ptr<char> cjid(strdup(jid.c_str()));
     auto_ptr<char> cpass(strdup(acc.password.c_str()));
+		auto_ptr<char> cserver(strdup(acc.server.c_str()));
 
     regmode = flogged = fonline = false;
 
     if(jc) delete jc;
 
-    jc = jab_new(cjid.get(), cpass.get(), acc.port,
+    jc = jab_new(cjid.get(), cpass.get(), cserver.get(), acc.port,
 	acc.additional["ssl"] == "1" ? 1 : 0);
 
     jab_packet_handler(jc, &packethandler);
@@ -136,7 +138,16 @@ void jabberhook::connect() {
 }
 
 void jabberhook::disconnect() {
+    // announce it to  everyone else
+    setjabberstatus(offline, "");
+
+    // announce it to the user
     statehandler(jc, JCONN_STATE_OFF);
+
+    // close the connection
+    jab_stop(jc);
+    delete(jc);
+    jc = 0;
 }
 
 void jabberhook::exectimers() {
@@ -520,8 +531,9 @@ const string &serv, string &err) {
 
     auto_ptr<char> cjid(strdup(jid.c_str()));
     auto_ptr<char> cpass(strdup(pass.c_str()));
+    auto_ptr<char> cserver(strdup(serv.c_str()));
 
-    jc = jab_new(cjid.get(), cpass.get(), port, 0);
+    jc = jab_new(cjid.get(), cpass.get(), cserver.get(), port, 0);
 
     if(!jc->user) {
 	err = _("Wrong nickname given, cannot register");
@@ -582,6 +594,11 @@ void jabberhook::setjabberstatus(imstatus st, string msg) {
 	case invisible:
 	    xmlnode_put_attrib(x, "type", "invisible");
 	    break;
+
+	case offline:
+	    xmlnode_put_attrib(x, "type", "unavailable");
+	    break;
+
     }
 
     map<string, string> add = conf.getourid(proto).additional;
@@ -1361,15 +1378,21 @@ void jabberhook::packethandler(jconn conn, jpacket packet) {
 	    x = xmlnode_get_tag(packet->x, "body");
 	    p = xmlnode_get_data(x); if(p) body = p;
 
-	    if(x = xmlnode_get_tag(packet->x, "subject")) {
-		body = (string) xmlnode_get_data (x) + ": " + body;
-	    }
-
-	    if(x = xmlnode_get_tag(packet->x, "x"))
-	    if(p = xmlnode_get_attrib(x, "xmlns"))
-	    if((string) p == "jabber:x:encrypted")
+	    if(x = xmlnode_get_tag(packet->x, "subject"))
 	    if(p = xmlnode_get_data(x))
-		enc = p;
+		body = (string) p + ": " + body;
+
+	    /* there can be multiple <x> tags. we're looking for one with
+	       xmlns = jabber:x:encrypted */
+
+	    for(x = xmlnode_get_firstchild(packet->x); x; x = xmlnode_get_nextsibling(x)) {
+		if((p = xmlnode_get_name(x)) && !strcmp(p, "x"))
+		if((p = xmlnode_get_attrib(x, "xmlns")) && !strcasecmp(p, "jabber:x:encrypted"))
+		if(p = xmlnode_get_data(x)) {
+		    enc = p;
+		    break;
+		}
+	    }
 
 	    if(!body.empty())
 		jhook.gotmessage(type, from, body, enc);
