@@ -1,7 +1,7 @@
 /*
 *
 * centericq rss handling class
-* $Id: rsshook.cc,v 1.22 2004/11/11 13:42:05 konst Exp $
+* $Id: rsshook.cc,v 1.23 2004/12/24 18:33:07 konst Exp $
 *
 * Copyright (C) 2003 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -418,6 +418,11 @@ void rsshook::parsedocument(const HTTPRequestEvent *rev, icqcontact *c) {
 		}
 	    }
 	}
+
+	while(!events.empty()) {
+	    delete events.back();
+	    events.pop_back();
+	}
     }
 
     if(c->inlist() && c->getdesc() != contactroot) {
