@@ -1,7 +1,7 @@
 /*
 *
 * centericq configuration handling routines
-* $Id: icqconf.cc,v 1.139 2005/01/26 23:52:47 konst Exp $
+* $Id: icqconf.cc,v 1.142 2005/05/23 14:16:52 konst Exp $
 *
 * Copyright (C) 2001-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -43,6 +43,7 @@
 icqconf::icqconf() {
     rs = rscard;
     rc = rcdark;
+    cm = cmproto;
     fgroupmode = nogroups;
 
     autoaway = autona = 0;
@@ -82,7 +83,7 @@ icqconf::imserver icqconf::defservers[protocolname_size] = {
     { "messenger.hotmail.com", 1863, 0 },
     { "toc.oscar.aol.com", 9898, 0 },
     { "irc.oftc.net", 6667, 0 },
-    { "jabber.com", 5222, 5223 },
+    { "jabber.org", 5222, 5223 },
     { "", 0, 0 },
     { "livejournal.com", 80, 0 },
     { "appmsg.gadu-gadu.pl", 80 }
@@ -237,6 +238,8 @@ void icqconf::loadkeys() {
 	    of << "bind contact\ti\tignore" << endl;
 	    of << "bind contact\t\\as\tquickfind" << endl;
 	    of << "bind contact\t/\tquickfind" << endl << endl;
+	    of << "bind contact\t\\cn\tnext_chat" << endl;
+	    of << "bind contact\t\\cb\tprev_chat" << endl;
 	    of << "bind history\t/\tsearch" << endl;
 	    of << "bind history\ts\tsearch" << endl;
 	    of << "bind history\tn\tsearch_again" << endl;
@@ -246,6 +249,8 @@ void icqconf::loadkeys() {
 	    of << "bind editor\t<esc>\tquit" << endl;
 	    of << "bind editor\t\\cp\tmultiple_recipients" << endl;
 	    of << "bind editor\t\\co\thistory" << endl;
+	    of << "bind editor\t\\cn\tnext_chat" << endl;
+	    of << "bind editor\t\\cb\tprev_chat" << endl;
 	    of << "bind editor\t\\a?\tinfo" << endl;
 	    of << "bind editor\t<F2>\tshow_urls" << endl;
 	    of << "bind editor\t<F9>\tfullscreen" << endl << endl;
@@ -259,7 +264,6 @@ void icqconf::loadkeys() {
     f.open(fname.c_str());
 
     if(f.is_open()) {
-
 	while(!f.eof()) {
 	    getstring(f, buf);
 
@@ -341,6 +345,8 @@ void icqconf::loadkeys() {
 	    if(param == "quit") k.action = key_quit; else
 	    if(param == "change_status") k.action = key_change_status; else
 	    if(param == "history") k.action = key_history; else
+	    if(param == "next_chat") k.action = key_next_chat; else
+	    if(param == "prev_chat") k.action = key_prev_chat; else
 	    if(param == "fetch_away_message") k.action = key_fetch_away_message; else
 	    if(param == "user_menu") k.action = key_user_menu; else
 	    if(param == "general_menu") k.action = key_general_menu; else
@@ -364,15 +370,54 @@ void icqconf::loadkeys() {
 	    if(param == "rss_check") k.action = key_rss_check; else
 	    if(param == "multiple_recipients") k.action = key_multiple_recipients; else
 	    if(param == "user_external_action") k.action = key_user_external_action;
-	    else continue;
+		else continue;
 
 	    keys.push_back(k);
 	}
+
 	f.close();
     }
+/*
+    if(face.action2key(key_info, section_contact).empty()) keys.push_back(keybinding()); else
+    if(face.action2key(key_quit, section_contact).empty()) 
+    if(face.action2key(key_change_status, section_contact).empty()) 
+    if(face.action2key(key_history, section_contact).empty()) 
+    if(face.action2key(key_fetch_away_message, section_contact).empty()) 
+    if(face.action2key(key_user_menu, section_contact).empty()) 
+    if(face.action2key(key_general_menu, section_contact).empty()) 
+    if(face.action2key(key_hide_offline, section_contact).empty()) 
+    if(face.action2key(key_contact_external_action, section_contact).empty()) 
+    if(face.action2key(key_add, section_contact).empty()) 
+    if(face.action2key(key_remove, section_contact).empty()) 
+    if(face.action2key(key_compose, section_contact).empty()) 
+    if(face.action2key(key_send_contact, section_contact).empty()) 
+    if(face.action2key(key_rss_check, section_contact).empty()) 
+    if(face.action2key(key_send_url, section_contact).empty()) 
+    if(face.action2key(key_rename, section_contact).empty()) 
+    if(face.action2key(key_version, section_contact).empty()) 
+    if(face.action2key(key_edit, section_contact).empty()) 
+    if(face.action2key(key_ignore, section_contact).empty()) 
+    if(face.action2key(key_quickfind, section_contact).empty()) 
+    if(face.action2key(key_next_chat, section_contact).empty()) 
+    if(face.action2key(key_prev_chat, section_contact).empty()) 
+    if(face.action2key(key_search, section_history).empty()) 
+    if(face.action2key(key_search_again, section_history).empty()) 
+    if(face.action2key(key_show_urls, section_history).empty()) 
+    if(face.action2key(key_fullscreen, section_history).empty()) 
+    if(face.action2key(key_send_message, section_editor).empty()) 
+    if(face.action2key(key_quit, section_editor).empty()) 
+    if(face.action2key(key_multiple_recipients, section_editor).empty()) 
+    if(face.action2key(key_history, section_editor).empty()) 
+    if(face.action2key(key_next_chat, section_editor).empty()) 
+    if(face.action2key(key_prev_chat, section_editor).empty()) 
+    if(face.action2key(key_info, section_editor).empty()) 
+    if(face.action2key(key_show_urls, section_editor).empty()) 
+    if(face.action2key(key_fullscreen, section_editor).empty()) 
+    if(face.action2key(key_show_urls, section_info).empty()) 
+    if(face.action2key(key_user_external_action, section_info).empty()) {}
+*/
 }
 
-
 void icqconf::loadmainconfig() {
     string fname = getconfigfname("config"), buf, param, rbuf;
     ifstream f(fname.c_str());
@@ -402,6 +447,8 @@ void icqconf::loadmainconfig() {
 	    if(param == "sockspass") sockspass = buf; else
 	    if((param == "usegroups") || (param == "group1")) fgroupmode = group1; else
 	    if(param == "group2") fgroupmode = group2; else
+	    if(param == "protocolormode") cm = icqconf::cmproto; else
+	    if(param == "statuscolormode") cm = icqconf::cmstatus; else
 	    if(param == "smtp") setsmtphost(buf); else
 	    if(param == "http_proxy") sethttpproxyhost(buf); else
 	    if(param == "log") makelog = true; else
@@ -519,6 +566,15 @@ void icqconf::save() {
 		case group2: f << "group2" << endl; break;
 	    }
 
+	    switch(getcolormode()) {
+		case cmproto:
+		    f << "protocolormode" << endl;
+		    break;
+		case cmstatus:
+		    f << "statuscolormode" << endl;
+		    break;
+	    }
+
 	    if(getmakelog()) f << "log" << endl;
 	    if(getproxyconnect()) f << "proxy_connect" << endl;
 	    if(getproxyssl()) f << "proxy_ssl" << endl;
@@ -560,6 +616,14 @@ void icqconf::loadcolors() {
 	    schemer.push(cp_clist_rss, "clist_rss    white/transparent   bold");
 	    schemer.push(cp_clist_lj, "clist_lj    cyan/transparent   bold");
 	    schemer.push(cp_clist_gadu, "clist_gg    blue/transparent   bold");
+	    schemer.push(cp_clist_online, "clist_online   green/transparent   bold");
+	    schemer.push(cp_clist_offline, "clist_offline   red/transparent   bold");
+	    schemer.push(cp_clist_away, "clist_away   yellow/transparent   bold");
+	    schemer.push(cp_clist_dnd, "clist_dnd   cyan/transparent   bold");
+	    schemer.push(cp_clist_na, "clist_na   blue/transparent   bold");
+	    schemer.push(cp_clist_free_for_chat, "clist_free_for_chat   green/transparent   bold");
+	    schemer.push(cp_clist_invisible, "clist_invisible   grey/transparent   bold");
+	    schemer.push(cp_clist_not_in_list, "clist_not_in_list   white/transparent   bold");
 	    break;
 
 	case rcblue:
@@ -586,6 +650,14 @@ void icqconf::loadcolors() {
 	    schemer.push(cp_clist_rss, "clist_rss    white/blue   bold");
 	    schemer.push(cp_clist_lj, "clist_lj    cyan/blue   bold");
 	    schemer.push(cp_clist_gadu, "clist_gg    blue/blue   bold");
+	    schemer.push(cp_clist_online, "clist_online   green/transparent   bold");
+	    schemer.push(cp_clist_offline, "clist_offline   red/transparent   bold");
+	    schemer.push(cp_clist_away, "clist_away   yellow/transparent   bold");
+	    schemer.push(cp_clist_dnd, "clist_dnd   cyan/transparent   bold");
+	    schemer.push(cp_clist_na, "clist_na   blue/transparent   bold");
+	    schemer.push(cp_clist_free_for_chat, "clist_free_for_chat   green/transparent   bold");
+	    schemer.push(cp_clist_invisible, "clist_invisible   grey/transparent   bold");
+	    schemer.push(cp_clist_not_in_list, "clist_not_in_list   white/transparent   bold");
 	    break;
     }
 
@@ -796,6 +868,14 @@ void icqconf::setregsound(icqconf::regsound s) {
     rs = s;
 }
 
+icqconf::colormode icqconf::getcolormode() const {
+    return cm;
+}
+
+void icqconf::setcolormode(colormode c) {
+    cm = c;
+}
+
 void icqconf::setauto(int away, int na) {
     autoaway = away;
     autona = na;
@@ -1050,6 +1130,20 @@ int icqconf::getprotcolor(protocolname pname) const {
     }
 }
 
+int icqconf::getstatuscolor(imstatus status) const {
+    switch(status) {
+        case offline : return getcolor(cp_clist_offline);
+        case available : return getcolor(cp_clist_online);
+        case invisible : return getcolor(cp_clist_invisible);
+        case freeforchat : return getcolor(cp_clist_free_for_chat);
+        case dontdisturb : return getcolor(cp_clist_dnd);
+        case occupied : return getcolor(cp_clist_occupied);
+        case notavail : return getcolor(cp_clist_na);
+        case away : return getcolor(cp_clist_away);
+	default : return getcolor(cp_main_text);
+    }
+}
+
 void icqconf::setbidi(bool fbidi) {
     bidi = fbidi;
 #ifdef USE_FRIBIDI
@@ -1223,7 +1317,7 @@ const string &dest, const string &number) const {
 	    exit(1);
 	}
 
-	delete c;
+	//delete c;
 	delete ev;
 
 	exit(0);
