@@ -1,7 +1,7 @@
 /*
 *
 * centericq user interface class
-* $Id: icqface.cc,v 1.241 2005/02/01 00:12:58 konst Exp $
+* $Id: icqface.cc,v 1.249 2005/08/28 01:33:21 konst Exp $
 *
 * Copyright (C) 2001-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -84,6 +84,15 @@ const char *strregcolor(icqconf::regcolor c) {
     return _("don't change");
 }
 
+const char *strcolormode(icqconf::colormode cm) {
+    switch(cm) {
+	case icqconf::cmproto : return _("protocol");
+	case icqconf::cmstatus : return _("status");
+    }
+
+    return _("don't change");
+}
+
 const char *strint(unsigned int i) {
     static char buf[64];
 
@@ -181,7 +190,7 @@ void icqface::init() {
 
     attrset(conf.getcolor(cp_status));
     mvhline(0, 0, ' ', COLS);
-    mvhline(LINES-1, 0, ' ', COLS);
+    mvhline(LINES, 0, ' ', COLS);
 
     inited = true;
     kt_resize_event = &termresize;
@@ -447,9 +456,42 @@ int icqface::generalmenu() {
     return r;
 }
 
+/* called to prepare the next chat contact, returns true if it found one, false otherwise
+   parameter is true if its next chat contact or false if is the previous
+ */
+bool icqface::next_chat(bool next) {
+  find_next_action = (next ? 1:-1);
+  if (last_selected) last_selected->setopenedforchat(false);
+  return true;
+}
+
+icqcontact *icqface::find_next_chat() {
+  if (find_next_action == 0) return 0;
+  int i;
+  if (last_selected){
+    for(i = 0; i < clist.count && clist.at(i) != last_selected; i++)
+      ;
+    i += find_next_action;
+  }
+  else i = find_next_action == 1 ? 0 : clist.count -1;
+
+  icqcontact *c;
+  for (; i < clist.count && i >= 0; i += find_next_action){
+    c = (icqcontact *) clist.at(i);
+    if (c->isopenedforchat() || c->hasevents()) {
+      find_next_action = 0;
+      extk = ACT_MSG;
+      return c;
+    }
+  }
+  
+  find_next_action = 0;
+  return 0;
+}
+
 icqcontact *icqface::mainloop(int &action) {
     int i, curid;
-    icqcontact *c = 0; icqgroup *g;
+    icqcontact *c = 0, *c1 = 0; icqgroup *g;
     bool fin;
 
     for(fin = false; !fin; ) {
@@ -457,10 +499,14 @@ icqcontact *icqface::mainloop(int &action) {
 
 	/* Obtain the (icqcontact *) from the treeview. If a node is
 	   selected, throw out the contact and obtain the correct (icqgroup *). */
+	
+	if (!(c = c1 = find_next_chat())){ //check if next_chat was called from inside a chat window
+	    last_selected = 0; // next_chat (if called) was called from contacts menu so there was no last selected contact
+	    c = (icqcontact *) mcontacts->open(&i);
+	    if ((c1 = find_next_chat())) c = c1; //check if next_chat was called from contacts menu
+	}
 
-	c = (icqcontact *) mcontacts->open(&i);
-
-	if(mcontacts->isnode(i) && c) {
+	if(!c1 && c && mcontacts->isnode(i)) {
 	    c = 0;
 	    g = (icqgroup *) mcontacts->getref(mcontacts->getid(mcontacts->menu.getpos()));
 	} else {
@@ -529,7 +575,7 @@ icqcontact *icqface::mainloop(int &action) {
 	    break;
 	}
     }
-
+    if (c) last_selected = c;
     return c;
 }
 
@@ -564,6 +610,8 @@ void icqface::fillcontactlist() {
 
     savec = mcontacts->getref(mcontacts->getid(mcontacts->menu.getpos()));
 
+    int ccolor = conf.getcolor(cp_main_text);
+
     if(!iscurrentnode && savec) {
 	ig = find(groups.begin(), groups.end(), ((icqcontact *) savec)->getgroupid());
 
@@ -691,10 +739,16 @@ void icqface::fillcontactlist() {
 	    !c->hasevents() && sc != '!')
 		continue;
 
+	if(conf.getcolormode() == icqconf::cmstatus) {
+	    ccolor = conf.getstatuscolor(c->getstatus());
+	} else {
+	    ccolor = conf.getprotcolor(c->getdesc().pname);
+	}
+
 	if(c->getstatus() == offline) {
 	    mcontacts->addleaff(nnode,
-		c->hasevents() ? conf.getcolor(cp_main_highlight) : conf.getprotcolor(c->getdesc().pname),
-		c, "%s%s ", c->hasevents() ? "#" : c->getpostponed().empty() ? " " : ">", dnick.c_str());
+		c->hasevents() ? conf.getcolor(cp_main_highlight) : ccolor,
+		c, "%s%s ", c->hasevents() ? "#" : c->getpostponed().empty() ? (c->isopenedforchat() ? "*" : " ") : ">", dnick.c_str());
 
 	} else {
 	    char *fmt = "%s[%c]%s%s ";
@@ -710,8 +764,8 @@ void icqface::fillcontactlist() {
 	    }
 
 	    mcontacts->addleaff(nnode,
-		c->hasevents() ? conf.getcolor(cp_main_highlight) : conf.getprotcolor(c->getdesc().pname),
-		c, fmt, c->hasevents() ? "#" : " ", shortstatus,
+		c->hasevents() ? conf.getcolor(cp_main_highlight) : ccolor,
+		c, fmt, c->hasevents() ? "#" : (c->isopenedforchat() ? "*" : " "), shortstatus,
 		c->getpostponed().empty() ? " " : ">", dnick.c_str());
 
 	}
@@ -1018,7 +1072,7 @@ void icqface::infogeneral(dialogbox &db, icqcontact *c) {
 	mainw.write(sizeWArea.x1+14, sizeWArea.y1+14, conf.getcolor(cp_main_text),
 	    ls ? strdateandtime(ls) : _("Never"));
 
-    } else {
+    } else if(c->getdesc() != contactroot) {
 	int days, hours, minutes, tdiff = timer_current-ls;
 
 	days = (int) (tdiff/86400);
@@ -2191,17 +2245,18 @@ void icqface::userinfoexternal(const imcontact &ic) {
 
 void icqface::showeventbottom(const imcontact &ic) {
     const char *text = ischannel(ic) ?
-	_("%s send, %s multi, %s history, %s URLs, %s expand, %s members, %s close") :
-	_("%s send, %s multi, %s history, %s URLs, %s expand, %s details, %s cancel");
+	_("%s send, %s multi, %s/%s pr/nxt chat, %s hist, %s URLs, %s expand, %s memb") :
+	_("%s send, %s multi, %s/%s pr/nxt chat, %s hist, %s URLs, %s expand, %s info");
 
     status(text,
 	getstatkey(key_send_message, section_editor).c_str(),
 	getstatkey(key_multiple_recipients, section_editor).c_str(),
+	getstatkey(key_prev_chat, section_editor).c_str(),
+	getstatkey(key_next_chat, section_editor).c_str(),
 	getstatkey(key_history, section_editor).c_str(),
 	getstatkey(key_show_urls, section_editor).c_str(),
 	getstatkey(key_fullscreen, section_editor).c_str(),
-	getstatkey(key_info, section_editor).c_str(),
-	getstatkey(key_quit, section_editor).c_str());
+	getstatkey(key_info, section_editor).c_str());
 }
 
 bool icqface::eventedit(imevent &ev) {
@@ -2449,8 +2504,8 @@ string icqface::extracttime(const imevent &ev) {
     time_t t, ts;
     char buf[64];
 
-    ds1 = time2str(&(t = ev.gettimestamp()), "DD.MM hh:mm", buf);
-    ds2 = time2str(&(ts = ev.getsenttimestamp()), "DD.MM hh:mm", buf);
+    ds1 = time2str(&(t = ev.gettimestamp()), "DD.MM.YY hh:mm", buf);
+    ds2 = time2str(&(ts = ev.getsenttimestamp()), "DD.MM.YY hh:mm", buf);
 
     r = ds1 + " ";
     tdiff = ts-t;
@@ -2620,6 +2675,7 @@ void icqface::chat(const imcontact &ic) {
     chatlastread = 0;
     inchat = true;
     passinfo = ic;
+    c->setopenedforchat(true);
 
     muins.clear();
     muins.push_back(passinfo);
@@ -2666,6 +2722,7 @@ void icqface::chat(const imcontact &ic) {
 	c->setpostponed(editdone ? "" : p.get());
     }
 
+    c->toggleopenedforchat();
     c->save();
     restoreworkarea();
     status("@");
@@ -3196,6 +3253,16 @@ int icqface::contactskeys(verticalmenu &m, int k) {
 	    face.extk = ACT_HISTORY;
 	    break;
 
+	case key_next_chat:
+	    face.extk = ACT_DUMMY;
+	    face.next_chat(true);
+	    break;
+	    
+	case key_prev_chat:
+	    face.extk = ACT_DUMMY;
+	    face.next_chat(false);
+	    break;
+
 	case key_add: face.extk = ACT_ADD; break;
 
 	case key_send_contact:
@@ -3323,6 +3390,14 @@ int icqface::editmsgkeys(texteditor &e, int k) {
 	case key_history:
 	    cicq.history(face.passinfo);
 	    break;
+	case key_prev_chat:
+	    face.editdone = false;
+	    face.next_chat(false);
+	    return -1;
+	case key_next_chat:
+	    face.editdone = false;
+	    face.next_chat(true);
+	    return -1;
 	case key_info:
 	    cicq.userinfo(face.passinfo);
 	    break;
@@ -3379,8 +3454,8 @@ int icqface::statuskeys(verticalmenu &m, int k) {
 }
 
 int icqface::fullscreenkeys(textbrowser &m, int k) {
-    switch(k) {
-	case KEY_F(9):
+    switch(face.key2action(k, section_editor)) {
+	case key_fullscreen:
 	    return 0;
     }
 
@@ -3434,7 +3509,7 @@ void icqface::xtermtitle(const string &text) {
 	string term = getenv("TERM") ? getenv("TERM") : "";
 
 	if(term == "xterm" || term == "Eterm" || term == "aterm"
-	|| term == "rxvt" || term == "screen")
+	|| term == "rxvt" || term.substr(0, 6) == "screen")
 	    cout << "\x1b]1;\x07\x1b]2;" << "centericq" << (text.empty() ? "" : (string) ": " + text) << "\x07" << flush;
     }
 }
