@@ -26,7 +26,7 @@ enum interfaceAction {
     ACT_FILE, ACT_GROUPMOVE, ACT_ORG_GROUPS, ACT_HIDEOFFLINE, ACT_FETCHAWAY,
     ACT_EMAIL, ACT_AUTH, ACT_CONTACT, ACT_VERSION, ACT_JOIN, ACT_LEAVE,
     ACT_CONFER, ACT_TRANSFERS, ACT_JOINDIALOG, ACT_EXTERN, ACT_RSS, ACT_LJ,
-    ACT_MASS_MOVE, ACT_PGPKEY, ACT_PGPSWITCH
+    ACT_MASS_MOVE, ACT_PGPKEY, ACT_PGPSWITCH, ACT_DUMMY
 };
 
 extern class centericq cicq;
@@ -92,6 +92,9 @@ class icqface {
 
 	imcontact passinfo;
 	const imevent *passevent;
+  
+	icqcontact *last_selected;
+	int find_next_action;
 
 	struct filetransferitem {
 	    string fname;
@@ -162,9 +165,6 @@ class icqface {
 	bool sprofmanager(string &name, string &act);
 	void showeventbottom(const imcontact &ic);
 
-	int key2action(int k, int s);
-	string action2key(int a, int s, int n = 1) const;
-
 	void invokelist(string &s, vector<string> &v, const string &def, textwindow *w);
 	bool setljparams(imxmlevent *ev);
 	void multichange(bool conv[], bool newstate);
@@ -202,6 +202,12 @@ class icqface {
 	void relaxedupdate();
 	bool updaterequested();
 
+	int key2action(int k, int s);
+	string action2key(int a, int s, int n = 1) const;
+  
+	icqcontact *find_next_chat();
+	bool next_chat(bool next = true);
+  
 	icqcontact *mainloop(int &action);
 	void fillcontactlist();
 
@@ -286,6 +292,7 @@ string getbdate(unsigned char fbday, unsigned char fbmonth, unsigned char fbyear
 
 const char *strregsound(icqconf::regsound s);
 const char *strregcolor(icqconf::regcolor c);
+const char *strcolormode(icqconf::colormode cm);
 const char *strint(unsigned int i);
 const char *strgroupmode(icqconf::groupmode gmode);
 const char *stryesno(bool b);
