@@ -1,9 +1,9 @@
 /*
 *
 * centericq user mode list class
-* $Id: icqmlist.cc,v 1.15 2002/08/16 16:48:27 konst Exp $
+* $Id: icqmlist.cc,v 1.17 2002/11/29 15:57:39 konst Exp $
 *
-* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2001,2002 by Konstantin Klyagin <konst@konst.org.ua>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -57,18 +57,14 @@ void icqlist::load() {
 		    pname = conf.getprotocolbyletter(buf[0]);
 
 		    switch(pname) {
-			case yahoo:
-			case msn:
-			case aim:
-			case irc:
-			    lst.push_back(modelistitem(nick, imcontact(nick,
-				pname), (contactstatus) i));
-			    break;
-
 			case icq:
 			    lst.push_back(modelistitem(nick, imcontact(strtoul(buf.c_str(),
 				0, 0), icq), (contactstatus) i));
 			    break;
+			default:
+			    lst.push_back(modelistitem(nick, imcontact(nick,
+				pname), (contactstatus) i));
+			    break;
 		    }
 		}
 	    }
