@@ -1,7 +1,7 @@
 /*
 *
 * centericq protocol specific user interface related routines
-* $Id: imcontroller.cc,v 1.54 2004/04/11 16:32:28 konst Exp $
+* $Id: imcontroller.cc,v 1.56 2004/07/20 22:16:40 konst Exp $
 *
 * Copyright (C) 2001-2004 by Konstantin Klyagin <konst@konst.org.ua>
 *
@@ -277,10 +277,6 @@ void imcontroller::msnupdateprofile() {
 	    icqcontact *c = clist.get(contactroot);
 	    c->setnick(tmp);
 	    mhook.sendupdateuserinfo(*c);
-
-	    char buf[512];
-	    sprintf(buf, _("Your friendly nickname has been changed to %s"), tmp.c_str());
-	    face.status(buf);
 	}
     } else {
 	face.status(_("You must be logged to the MSN network to update the friendly nick"));
@@ -317,7 +313,7 @@ void imcontroller::gaduupdateprofile() {
 	    ghook.sendupdateuserinfo(*c);
 
     } else {
-	face.status(_("You must be logged to the Jabber network to update your details"));
+	face.status(_("You must be logged to the Gadu-Gadu network to update your details"));
     }
 #endif
 }
